"use strict";

var timer;
var startPage= 'kysely.html';

window.onload = function() { 
    
	var btnJatka = document.getElementById('aloita');

	btnJatka.addEventListener("click", valmis);	
	
//    timer = setTimeout(function() {			// Start again in 10 seconds
//                window.location.href = startPage;
//            }, 10000);
}

function valmis() {
	
	clearTimeout(timer);
	
	window.location.href = startPage;
}
