"use strict";

var timer;
var nextPage= 'intro.html';

window.onload = function() { 
    
	var btnJatka = document.getElementById('aloita');

	btnJatka.addEventListener("click", jatka);	
	
//    timer = setTimeout(function() {			// Start asking in 3 seconds
//			window.location.href = nextPage;
//        }, 3000);

}

function jatka() {
	
	clearTimeout(timer);
	
	window.location.href = nextPage;
}
